@@ -26,7 +26,7 @@ __author__ = ["Rafael Pastrana"]
 __copyright__ = "Copyright 2020 - Princeton University"
 __license__ = "MIT License"
 __email__ = "arpj@princeton.edu"
-__version__ = "0.2.1"
+__version__ = "0.4.0"
 
 
 # Directories
@@ -41,31 +41,20 @@ JSON_DATA = os.path.abspath(os.path.join(DATA, "json"))
 COLORS = {"tension": (227, 6, 75),  # red
           "compression": (12, 119, 184),  # blue
           "edge": (50, 50, 50),  # dark gray
-          "node": (255, 255, 255),  # green
+          "node": (255, 255, 255),  # white
           "node_support": (0, 150, 10),  # green
           "node_origin": (155, 100, 255),  # purple
-          "support_force": (0, 0, 30),  # dark gray / green (0, 150, 10)
+          "support_force": (75, 75, 75),  # dark gray / green (0, 150, 10)
           "load": (0, 150, 10),  # green / light green (50, 250, 100)
           "trail": (250, 80, 210),  # pink
           "auxiliary_trail": (255, 155, 15)}  # orange
 
 PROXY_PORT = 7123
 
-__all_plugins__ = ['compas_cem.ghpython.install', 'compas_cem.ghpython.uninstall']
+# TODO: add static equilibrium plugin
+__all_plugins__ = ['compas_cem.ghpython.install',
+                   'compas_cem.ghpython.uninstall',
+                   'compas_cem.ghpython.register',
+                   'compas_cem.plotters.register']
+
 __all__ = ["HOME", "DATA", "DOCS", "TEMP", "JSON_DATA", "COLORS"]
-
-
-# ==============================================================================
-# Base element
-# ==============================================================================
-
-class Data(object):
-    """
-    Base class for all COMPAS data objects
-    The base element.
-    """
-    def ToString(self):
-        """
-        Show object representation as string in Rhino/Grasshopper.
-        """
-        return self.__repr__()
