@@ -5,9 +5,9 @@ class DeviationEdge(Edge):
     """
     A deviation edge.
     """
-    def __init__(self, u, v, force):
-        super(DeviationEdge, self).__init__(u, v)
-        self.attributes = {"force": force, "type": "deviation"}
+    def __init__(self, u, v, force, **kwargs):
+        attrs = {"force": force, "type": "deviation"}
+        super(DeviationEdge, self).__init__(u, v, attrs, **kwargs)
 
     def __repr__(self):
         """
