@@ -3,7 +3,7 @@ Draw a form diagram.
 """
 from ghpythonlib.componentbase import executingcomponent as component
 
-from compas_cem.ghpython import FormArtist
+from compas.artists import Artist
 
 
 class FormArtistComponent(component):
@@ -12,8 +12,9 @@ class FormArtistComponent(component):
         edge_keys = edge_keys or None
         force_min = force_min or 1e-3
         force_scale = force_scale or 1
+
         if form:
-            artist = FormArtist(form)
+            artist = Artist(form)
 
             nodes = artist.draw_nodes(node_keys)
             edges = artist.draw_edges(edge_keys)
