@@ -3,7 +3,7 @@ Draw a topology diagram.
 """
 from ghpythonlib.componentbase import executingcomponent as component
 
-from compas_cem.ghpython import TopologyArtist
+from compas.artists import Artist
 
 
 class TopologyArtistComponent(component):
@@ -12,8 +12,9 @@ class TopologyArtistComponent(component):
         edge_keys = edge_keys or None
         force_min = force_min or 1e-3
         force_scale = force_scale or 1.0
+
         if topology:
-            artist = TopologyArtist(topology)
+            artist = Artist(topology)
 
             nodes = artist.draw_nodes(node_keys)
             origin_nodes = artist.draw_nodes_origin(node_keys)
