@@ -7,8 +7,8 @@ from compas_cem.equilibrium import static_equilibrium
 
 
 class FormFindingComponent(component):
-    def RunScript(self, topology, tmax, eta_min):
+    def RunScript(self, topology, tmax, eta):
         tmax = tmax or 100
-        eta_min = eta_min or 1e-6
+        eta = eta or 1e-6
         if topology:
-            return static_equilibrium(topology, tmax=tmax, eta=eta_min)
+            return static_equilibrium(topology, tmax=tmax, eta=eta)
