@@ -12,7 +12,8 @@ Classes
     :toctree: generated/
     :nosignatures:
 
-    FormPlotter
+    FormArtist
+    TopologyArtist
 """
 
 from __future__ import absolute_import
@@ -21,13 +22,8 @@ from __future__ import print_function
 
 
 # from .<module> import *
-import compas
-
-if not compas.IPY:
-    from .form_plotter import *  # noqa F403
-    from .topology_plotter import *  # noqa F403
-
-from .proxy import *  # noqa F403
-
+from .formartist import *  # noqa F403
+from .topologyartist import *  # noqa F403
+# from .proxy import *  # noqa F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
